# -*- coding: utf-8 -*-
from Components.config import config, ConfigText
from Components.Converter.Converter import Converter
from Components.Element import cached
from ServiceReference import ServiceReference
from enigma import eServiceCenter, eServiceReference, iServiceInformation, iPlayableService, eDVBFrontendParametersSatellite, eDVBFrontendParametersCable
from string import upper
import gettext

class ExtendedServiceInfo(Converter, object):
	TUNERINFO = 0

	def __init__(self, type):
		Converter.__init__(self, type)
		self.list = []
		self.getList()
		
		if type == "TunerInfo":
			self.type = self.TUNERINFO

	@cached
	def getText(self):
		service = self.source.service
		info = service and service.info()
		if not info:
			return ""
		
		text = ""
		
		tunerinfo = self.getTunerInfo(service)

		if self.type == self.TUNERINFO:
			text = tunerinfo

		return text

	text = property(getText)

	def changed(self, what):
		Converter.changed(self, what)


	def getList(self):
		serviceHandler = eServiceCenter.getInstance()
		services = serviceHandler.list(eServiceReference('1:7:1:0:0:0:0:0:0:0:(type == 1) || (type == 17) || (type == 195) || (type == 25) FROM BOUQUET "bouquets.tv" ORDER BY bouquet'))
		bouquets = services and services.getContent("SN", True)
		
		for bouquet in bouquets:
			services = serviceHandler.list(eServiceReference(bouquet[0]))
			channels = services and services.getContent("SN", True)
			
			for channel in channels:
				if not channel[0].startswith("1:64:"): # Ignore marker
					self.list.append(channel[1].replace('\xc2\x86', '').replace('\xc2\x87', ''))


	def getTunerInfo(self, service):
		tunerinfo = ""
		feinfo = (service and service.frontendInfo())
		if (feinfo is not None):
			frontendData = (feinfo and feinfo.getAll(True))
			if (frontendData is not None):
				if ((frontendData.get("tuner_type") == "DVB-S") or (frontendData.get("tuner_type") == "DVB-C")):
					frequency = (str((frontendData.get("frequency") / 1000)) + " MHz")
					symbolrate = str(int(frontendData.get("symbol_rate", 0) / 1000))
					if (frontendData.get("tuner_type") == "DVB-S"):
						pol = {
								eDVBFrontendParametersSatellite.Polarisation_Horizontal : "H",
								eDVBFrontendParametersSatellite.Polarisation_Vertical : "V",
								eDVBFrontendParametersSatellite.Polarisation_CircularLeft : "CL",
								eDVBFrontendParametersSatellite.Polarisation_CircularRight : "CR"
							}[frontendData.get("polarization", eDVBFrontendParametersSatellite.Polarisation_Horizontal)]
					else:
						polarisation = 0
					fec = {
								eDVBFrontendParametersSatellite.FEC_None : "None",
								eDVBFrontendParametersSatellite.FEC_Auto : "Auto",
								eDVBFrontendParametersSatellite.FEC_1_2 : "1/2",
								eDVBFrontendParametersSatellite.FEC_2_3 : "2/3",
								eDVBFrontendParametersSatellite.FEC_3_4 : "3/4",
								eDVBFrontendParametersSatellite.FEC_5_6 : "5/6",
								eDVBFrontendParametersSatellite.FEC_7_8 : "7/8",
								eDVBFrontendParametersSatellite.FEC_3_5 : "3/5",
								eDVBFrontendParametersSatellite.FEC_4_5 : "4/5",
								eDVBFrontendParametersSatellite.FEC_8_9 : "8/9",
								eDVBFrontendParametersSatellite.FEC_9_10 : "9/10"
							}[frontendData.get("fec_inner", eDVBFrontendParametersSatellite.FEC_Auto)]
					orb = {
									3590:'Thor/Intelsat (1.0W)',3560:'Amos (4.0W)',3550:'Atlantic Bird (5.0W)',3530:'Nilesat/Atlantic Bird (7.0W)',
									3520:'Atlantic Bird (8.0W)',3475:'Atlantic Bird (12.5W)',3460:'Express (14.0W)', 3450:'Telstar (15.0W)',
									3420:'Intelsat (18.0W)',3380:'Nss (22.0W)',3355:'Intelsat (24.5W)', 3325:'Intelsat (27.5W)',3300:'Hispasat (30.0W)',
									3285:'Intelsat (31.5W)',3170:'Intelsat (43.0W)',3150:'Intelsat (45.0W)',
									750:'Abs (75.0E)',720:'Intelsat (72.0E)',705:'Eutelsat W5 (70.5E)',685:'Intelsat (68.5E)',620:'Intelsat 902 (62.0E)',
									600:'Intelsat 904 (60.0E)',570:'Nss (57.0E)',530:'Express AM22 (53.0E)',480:'Eutelsat 2F2 (48.0E)',450:'Intelsat (45.0E)',
									420:'Turksat 2A (42.0E)',400:'Express AM1 (40.0E)',390:'Hellas Sat 2 (39.0E)',380:'Paksat 1 (38.0E)',
									360:'Eutelsat Sesat (36.0E)',335:'Astra 1M (33.5E)',330:'Eurobird 3 (33.0E)',	328:'Galaxy 11 (32.8E)',
									315:'Astra 5A (31.5E)',310:'Turksat (31.0E)',305:'Arabsat (30.5E)',285:'Eurobird 1 (28.5E)',
									284:'Eurobird/Astra (28.2E)',282:'Eurobird/Astra (28.2E)',
									260:'Badr 3/4 (26.0E)',255:'Eurobird 2 (25.5E)',235:'Astra 1E (23.5E)',215:'Eutelsat (21.5E)',
									216:'Eutelsat W6 (21.6E)',210:'AfriStar 1 (21.0E)',192:'Astra 1F (19.2E)',160:'Eutelsat W2 (16.0E)',
									130:'Hot Bird 6,7A,8 (13.0E)',100:'Eutelsat W1 (10.0E)',90:'Eurobird 9 (9.0E)',70:'Eutelsat W3A (7.0E)',
									50:'Sirius 4 (5.0E)',48:'Sirius 4 (4.8E)',30:'Telecom 2 (3.0E)'
								}[frontendData.get("orbital_position", "None")]		
					tunerinfo = (frequency + "  " + pol + "  " + fec + "  " + symbolrate + "  " + orb)
				return tunerinfo
		else:
			return ""

